@@ -1,14 +1,20 @@
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Dict, Optional, Type, TypeVar
 
 import attr
 
 from ..types import UNSET
 from ..util.serialization import is_not_none
 
+T = TypeVar("T", bound="Parameter")
+
 
 @attr.s(auto_attribs=True)
 class Parameter:
-    """ A parameter to an operation. """
+    """A parameter to an operation.
+
+    Attributes:
+        name (str): The name of the parameter, such as the name of a mathematical symbol.
+    """
 
     name: str
 
@@ -28,12 +34,12 @@ class Parameter:
 
         return field_dict
 
-    @staticmethod
-    def from_dict(src_dict: Dict[str, Any]) -> "Parameter":
+    @classmethod
+    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
         name = d.pop("name")
 
-        parameter = Parameter(
+        parameter = cls(
             name=name,
         )
 
